EXPORTS
	??0CWsGraphicDrawer@@IAE@XZ @ 1 NONAME ; CWsGraphicDrawer::CWsGraphicDrawer(void)
	??0TWsGraphicMsgAnimation@@QAE@XZ @ 2 NONAME ; TWsGraphicMsgAnimation::TWsGraphicMsgAnimation(void)
	??0TWsGraphicMsgBufParser@@QAE@ABVTDesC8@@@Z @ 3 NONAME ; TWsGraphicMsgBufParser::TWsGraphicMsgBufParser(class TDesC8 const &)
	??1CWsGraphicDrawer@@UAE@XZ @ 4 NONAME ; CWsGraphicDrawer::~CWsGraphicDrawer(void)
	?AddLC@CWsGraphicDrawerArray@@QAEXPAVCWsGraphicDrawer@@@Z @ 5 NONAME ; void CWsGraphicDrawerArray::AddLC(class CWsGraphicDrawer *)
	?Animate@MWsAnimationScheduler@@IAEXAAVMWsScreen@@@Z @ 6 NONAME ; void MWsAnimationScheduler::Animate(class MWsScreen &)
	?AnimationTime@TWsGraphicMsgAnimation@@QBE?AVTTimeIntervalMicroSeconds@@ABVTTime@@ABV2@@Z @ 7 NONAME ; class TTimeIntervalMicroSeconds TWsGraphicMsgAnimation::AnimationTime(class TTime const &, class TTimeIntervalMicroSeconds const &) const
	?BaseConstructL@CWsGraphicDrawer@@IAEXAAVMWsGraphicDrawerEnvironment@@ABUTGraphicDrawerId@@AAVMWsClient@@@Z @ 8 NONAME ; void CWsGraphicDrawer::BaseConstructL(class MWsGraphicDrawerEnvironment &, struct TGraphicDrawerId const &, class MWsClient &)
	?Close@CWsGraphicDrawerArray@@QAEXXZ @ 9 NONAME ; void CWsGraphicDrawerArray::Close(void)
	?Compare@TGraphicDrawerId@@QBEHABU1@@Z @ 10 NONAME ; int TGraphicDrawerId::Compare(struct TGraphicDrawerId const &) const
	?Compare@TGraphicDrawerId@@SAHABU1@0@Z @ 11 NONAME ; int TGraphicDrawerId::Compare(struct TGraphicDrawerId const &, struct TGraphicDrawerId const &)
	?Contains@CWsGraphicDrawer@@QBEHABV?$TArray@UTGraphicDrawerId@@@@@Z @ 12 NONAME ; int CWsGraphicDrawer::Contains(class TArray<struct TGraphicDrawerId> const &) const
	?Count@TWsGraphicMsgBufParser@@QBEHXZ @ 13 NONAME ; int TWsGraphicMsgBufParser::Count(void) const
	?CreateLC@WsGraphicDrawer@@SAPAVCWsGraphicDrawer@@VTUid@@AAVMWsGraphicDrawerEnvironment@@ABUTGraphicDrawerId@@AAVMWsClient@@ABVTDesC8@@@Z @ 14 NONAME ; class CWsGraphicDrawer * WsGraphicDrawer::CreateLC(class TUid, class MWsGraphicDrawerEnvironment &, struct TGraphicDrawerId const &, class MWsClient &, class TDesC8 const &)
	?Data@TWsGraphicMsgBufParser@@QBE?AVTPtrC8@@H@Z @ 15 NONAME ; class TPtrC8 TWsGraphicMsgBufParser::Data(int) const
	?Draw@CWsGraphicDrawer@@QBEXAAVMWsGc@@ABVTRect@@ABVTDesC8@@@Z @ 16 NONAME ; void CWsGraphicDrawer::Draw(class MWsGc &, class TRect const &, class TDesC8 const &) const
	?Env@CWsGraphicDrawer@@IAEAAVMWsGraphicDrawerEnvironment@@XZ @ 17 NONAME ; class MWsGraphicDrawerEnvironment & CWsGraphicDrawer::Env(void)
	?Find@TWsGraphicMsgBufParser@@QBEHVTUid@@H@Z @ 18 NONAME ; int TWsGraphicMsgBufParser::Find(class TUid, int) const
	?HasAsChild@CWsGraphicDrawer@@EBEHABV?$TArray@UTGraphicDrawerId@@@@@Z @ 19 NONAME ; int CWsGraphicDrawer::HasAsChild(class TArray<struct TGraphicDrawerId> const &) const
	?Id@CWsGraphicDrawer@@QBEABUTGraphicDrawerId@@XZ @ 20 NONAME ; struct TGraphicDrawerId const & CWsGraphicDrawer::Id(void) const
	?Invalidate@CWsGraphicDrawer@@IAEXXZ @ 21 NONAME ; void CWsGraphicDrawer::Invalidate(void)
	?IsEmpty@CWsGraphicDrawerArray@@QBEHXZ @ 22 NONAME ; int CWsGraphicDrawerArray::IsEmpty(void) const
	?IsPlaying@TWsGraphicMsgAnimation@@QBEHABVTTime@@ABVTTimeIntervalMicroSeconds@@@Z @ 23 NONAME ; int TWsGraphicMsgAnimation::IsPlaying(class TTime const &, class TTimeIntervalMicroSeconds const &) const
	?IsSharedWith@CWsGraphicDrawer@@QBEHVTSecureId@@@Z @ 24 NONAME ; int CWsGraphicDrawer::IsSharedWith(class TSecureId) const
	?Load@TWsGraphicMsgAnimation@@QAEHABVTWsGraphicMsgBufParser@@@Z @ 25 NONAME ; int TWsGraphicMsgAnimation::Load(class TWsGraphicMsgBufParser const &)
	?Load@TWsGraphicMsgAnimation@@QAEHABVTWsGraphicMsgBufParser@@H@Z @ 26 NONAME ; int TWsGraphicMsgAnimation::Load(class TWsGraphicMsgBufParser const &, int)
	?Owner@CWsGraphicDrawer@@QBEABVMWsClient@@XZ @ 27 NONAME ; class MWsClient const & CWsGraphicDrawer::Owner(void) const
	?Redraw@MWsAnimationScheduler@@IAEXAAVMWsScreen@@@Z @ 28 NONAME ; void MWsAnimationScheduler::Redraw(class MWsScreen &)
	?RedrawInvalid@MWsAnimationScheduler@@IAEHAAVMWsScreen@@ABV?$TArray@UTGraphicDrawerId@@@@@Z @ 29 NONAME ; int MWsAnimationScheduler::RedrawInvalid(class MWsScreen &, class TArray<struct TGraphicDrawerId> const &)
	?Remove@CWsGraphicDrawerArray@@QAEHABUTGraphicDrawerId@@@Z @ 30 NONAME ; int CWsGraphicDrawerArray::Remove(struct TGraphicDrawerId const &)
	?RemoveAll@CWsGraphicDrawerArray@@QAEHABVMWsClient@@@Z @ 31 NONAME ; int CWsGraphicDrawerArray::RemoveAll(class MWsClient const &)
	?RemoveAndDestroy@CWsGraphicDrawerArray@@QAEHABUTGraphicDrawerId@@@Z @ 32 NONAME ; int CWsGraphicDrawerArray::RemoveAndDestroy(struct TGraphicDrawerId const &)
	?RemoveAndDestroyAll@CWsGraphicDrawerArray@@QAEHABVMWsClient@@@Z @ 33 NONAME ; int CWsGraphicDrawerArray::RemoveAndDestroyAll(class MWsClient const &)
	?ResetAndDestroy@CWsGraphicDrawerArray@@QAEXXZ @ 34 NONAME ; void CWsGraphicDrawerArray::ResetAndDestroy(void)
	?ResolveGraphic@CWsGraphicDrawerArray@@QBEPBVCWsGraphicDrawer@@ABUTGraphicDrawerId@@@Z @ 35 NONAME ; class CWsGraphicDrawer const * CWsGraphicDrawerArray::ResolveGraphic(struct TGraphicDrawerId const &) const
	?ResolveObjectInterface@MWsObjectProvider@@UAEPAXI@Z @ 36 NONAME ; void * MWsObjectProvider::ResolveObjectInterface(unsigned int)
	?SendMessage@CWsGraphicDrawer@@IAEHABVTDesC8@@@Z @ 37 NONAME ; int CWsGraphicDrawer::SendMessage(class TDesC8 const &)
	?Share@CWsGraphicDrawer@@QAEHVTSecureId@@@Z @ 38 NONAME ; int CWsGraphicDrawer::Share(class TSecureId)
	?ShareGlobally@CWsGraphicDrawer@@QAEHXZ @ 39 NONAME ; int CWsGraphicDrawer::ShareGlobally(void)
	?SwapLC@CWsGraphicDrawerArray@@QAEHPAVCWsGraphicDrawer@@@Z @ 40 NONAME ; int CWsGraphicDrawerArray::SwapLC(class CWsGraphicDrawer *)
	?Uid@TWsGraphicMsgBufParser@@QBE?AVTUid@@H@Z @ 41 NONAME ; class TUid TWsGraphicMsgBufParser::Uid(int) const
	?UnShare@CWsGraphicDrawer@@QAEHVTSecureId@@@Z @ 42 NONAME ; int CWsGraphicDrawer::UnShare(class TSecureId)
	?UnShareGlobally@CWsGraphicDrawer@@QAEHXZ @ 43 NONAME ; int CWsGraphicDrawer::UnShareGlobally(void)
	?Verify@TWsGraphicMsgBufParser@@QBEHXZ @ 44 NONAME ; int TWsGraphicMsgBufParser::Verify(void) const
	?Env@CWsGraphicDrawer@@IBEABVMWsGraphicDrawerEnvironment@@XZ @ 45 NONAME ; class MWsGraphicDrawerEnvironment const & CWsGraphicDrawer::Env(void) const
	?HandleEvent@CWsGraphicDrawer@@QAEXABUTWservCrEvent@@@Z @ 46 NONAME ; void CWsGraphicDrawer::HandleEvent(struct TWservCrEvent const &)
	?HasEventHandler@CWsGraphicDrawer@@QBEHXZ @ 47 NONAME ; int CWsGraphicDrawer::HasEventHandler(void) const
	?SetEventHandler@CWsGraphicDrawer@@QAEXPAVMWsEventHandler@@@Z @ 48 NONAME ; void CWsGraphicDrawer::SetEventHandler(class MWsEventHandler *)
	??0TWservCrEvent@@QAE@K@Z @ 49 NONAME ; TWservCrEvent::TWservCrEvent(unsigned long)
	??0TWservCrEvent@@QAE@KK@Z @ 50 NONAME ; TWservCrEvent::TWservCrEvent(unsigned long, unsigned long)
	??0TWservCrEvent@@QAE@KKPAX@Z @ 51 NONAME ; TWservCrEvent::TWservCrEvent(unsigned long, unsigned long, void *)
	?SizeMode@TWservCrEvent@@QBEHXZ @ 52 NONAME ; int TWservCrEvent::SizeMode(void) const
	?Type@TWservCrEvent@@QBEKXZ @ 53 NONAME ; unsigned long TWservCrEvent::Type(void) const
	?VisibleRegion@TWservCrEvent@@QBEPBVRRegion@@XZ @ 54 NONAME ; class RRegion const * TWservCrEvent::VisibleRegion(void) const
	?ScreenNumber@TWservCrEvent@@QBEHXZ @ 55 NONAME ; int TWservCrEvent::ScreenNumber(void) const
	?LoadFixed@TWsGraphicMsgBufParser@@QBEHVTUid@@PAXHH@Z @ 56 NONAME ; int TWsGraphicMsgBufParser::LoadFixed(class TUid, void *, int, int) const
	?SendMessage@CWsGraphicDrawer@@IAEHAAVCWsMessageData@@@Z @ 57 NONAME ; int CWsGraphicDrawer::SendMessage(class CWsMessageData &)
	?DrawingRegion@TWservCrEvent@@QBEPBVTRegion@@XZ @ 58 NONAME ; class TRegion const * TWservCrEvent::DrawingRegion(void) const
	?WindowGroupIdentifier@TWservCrEvent@@QBEHXZ @ 59 NONAME ; int TWservCrEvent::WindowGroupIdentifier(void) const
	?Add@CWsGraphicDrawerArray@@QAEHPAVCWsGraphicDrawer@@@Z @ 60 NONAME ; int CWsGraphicDrawerArray::Add(class CWsGraphicDrawer *)
	?AddTLC@CWsGraphicDrawerArray@@QAEPAUXRollBackBase@1@PAVCWsGraphicDrawer@@@Z @ 61 NONAME ; struct CWsGraphicDrawerArray::XRollBackBase * CWsGraphicDrawerArray::AddTLC(class CWsGraphicDrawer *)
	?CommitP@CWsGraphicDrawerArray@@QAEXPAUXRollBackBase@1@@Z @ 62 NONAME ; void CWsGraphicDrawerArray::CommitP(struct CWsGraphicDrawerArray::XRollBackBase *)
	?RemoveTLC@CWsGraphicDrawerArray@@QAEPAUXRollBackBase@1@ABUTGraphicDrawerId@@@Z @ 63 NONAME ; struct CWsGraphicDrawerArray::XRollBackBase * CWsGraphicDrawerArray::RemoveTLC(struct TGraphicDrawerId const &)
	?Swap@CWsGraphicDrawerArray@@QAEHPAVCWsGraphicDrawer@@@Z @ 64 NONAME ; int CWsGraphicDrawerArray::Swap(class CWsGraphicDrawer *)
	?SwapTLC@CWsGraphicDrawerArray@@QAEPAUXRollBackBase@1@PAVCWsGraphicDrawer@@@Z @ 65 NONAME ; struct CWsGraphicDrawerArray::XRollBackBase * CWsGraphicDrawerArray::SwapTLC(class CWsGraphicDrawer *)
	?Orientation@TWservCrEvent@@QBE?AW4TGraphicsOrientation@CFbsBitGc@@XZ @ 66 NONAME ; enum CFbsBitGc::TGraphicsOrientation TWservCrEvent::Orientation(void) const
	?FinalClose@WsGraphicDrawer@@SAXXZ @ 67 NONAME ; void WsGraphicDrawer::FinalClose(void)
	?WasVisible@TWservCrEvent@@QBEHXZ @ 68 NONAME ; int TWservCrEvent::WasVisible(void) const
	??0TWservCrEvent@@QAE@KKPAXPAVMWsWindow@@@Z @ 69 NONAME ; TWservCrEvent::TWservCrEvent(unsigned long, unsigned long, void *, class MWsWindow *)
	?Window@TWservCrEvent@@QBEPAVMWsWindow@@XZ @ 70 NONAME ; class MWsWindow * TWservCrEvent::Window(void) const
	??0CWsPlugin@@IAE@XZ @ 71 NONAME ; CWsPlugin::CWsPlugin(void)
	??0CWsRenderStage@@IAE@XZ @ 72 NONAME ; CWsRenderStage::CWsRenderStage(void)
	??1CWsPlugin@@UAE@XZ @ 73 NONAME ; CWsPlugin::~CWsPlugin(void)
	??1CWsRenderStage@@UAE@XZ @ 74 NONAME ; CWsRenderStage::~CWsRenderStage(void)
	?BaseConstructL@CWsPlugin@@IAEXAAVMWsGraphicDrawerEnvironment@@@Z @ 75 NONAME ; void CWsPlugin::BaseConstructL(class MWsGraphicDrawerEnvironment &)
	?BaseConstructL@CWsRenderStage@@IAEXXZ @ 76 NONAME ; void CWsRenderStage::BaseConstructL(void)
	?Env@CWsPlugin@@IAEAAVMWsGraphicDrawerEnvironment@@XZ @ 77 NONAME ; class MWsGraphicDrawerEnvironment & CWsPlugin::Env(void)
	?Env@CWsPlugin@@IBEABVMWsGraphicDrawerEnvironment@@XZ @ 78 NONAME ; class MWsGraphicDrawerEnvironment const & CWsPlugin::Env(void) const
	?Next@CWsRenderStage@@UAEPAV1@XZ @ 79 NONAME ; class CWsRenderStage * CWsRenderStage::Next(void)
	?PluginName@CWsPlugin@@UBEABVTDesC16@@XZ @ 80 NONAME ; class TDesC16 const & CWsPlugin::PluginName(void) const
	?ResolveObjectInterface@CWsRenderStage@@UAEPAXI@Z @ 81 NONAME ; void * CWsRenderStage::ResolveObjectInterface(unsigned int)
	?SetNext@CWsRenderStage@@UAEXPAV1@@Z @ 82 NONAME ; void CWsRenderStage::SetNext(class CWsRenderStage *)
	?SurfaceId@TWservCrEvent@@QBEPBVTSurfaceId@@XZ @ 83 NONAME ; class TSurfaceId const * TWservCrEvent::SurfaceId(void) const
	?Animate@MWsAnimationScheduler@@IAEXAAVMWsScreen@@PAVTRequestStatus@@@Z @ 84 NONAME ; void MWsAnimationScheduler::Animate(class MWsScreen &, class TRequestStatus *)
